@@ -13,7 +13,7 @@ and signing orders and then collecting the results from the BankID servers.
 
 If you intend to use PyBankID in your project, you are advised to read
 the `BankID Relying Party Guidelines
-<https://www.bankid.com/bankid-i-dina-tjanster/rp-info>`_ before
+<https://www.bankid.com/utvecklare/rp-info>`_ before
 doing anything else. There, one can find information
 about how the BankID methods are defined and how to use them.
 
